@@ -36,20 +36,24 @@ def create_lyric_static(arr_comp, mix_data, font_url, lyric_lines=2):
 
 def load_lyric_video(arr_id, wait_time=10*60):
     util_time=time.time()+wait_time
-    arr_video_path=[]
-    arr_id_downloaded=[]
-    while time.time() < util_time and len(arr_video_path) < len(arr_id):
+    arr_video_path = []
+    arr_id_downloaded = []
+    arr_rs = {}
+    while time.time() < util_time and len(arr_id_downloaded) < len(arr_id):
         for idx in arr_id:
             if idx not in arr_id_downloaded:
                 try:
                     obj = requests.get(f"http://api-magicframe.automusic.win/static-lyric/load/{idx}").json()
                     if "id" in obj and int(obj['status']) == 3:
                         arr_id_downloaded.append(idx)
-                        path_video=download_file(obj['result'])
-                        arr_video_path.append(path_video)
-                        if len(arr_video_path) == len(arr_id):
+                        path_video = download_file(obj['result'])
+                        arr_rs[idx] = path_video
+                        if len(arr_id_downloaded) == len(arr_id):
                             break
                 except:
                     pass
         time.sleep(10)
+    for idx in arr_id:
+        if idx in arr_rs:
+            arr_video_path.append(arr_rs[idx])
     return arr_video_path
\ No newline at end of file
