@@ -1,4 +1,4 @@
-import youtube_dl, requests
+import yt_dlp, requests
 from bgeditor.common.utils import get_dir, download_file,normal_audio
 from bgeditor.dao.FFmpeg import create_loop_audio_times
 import uuid,json, shutil,os
@@ -14,7 +14,7 @@ def download_audio(url, ext='mp3', retries= 3):
             'outtmpl': rs,
             'format': 'bestaudio/m4a',
         }
-        with youtube_dl.YoutubeDL(ydl_opts) as ydl:
+        with yt_dlp.YoutubeDL(ydl_opts) as ydl:
             ydl.download([url])
     except Exception:
         if(retries<0):
